Comment

Struct Comment 

#[non_exhaustive]
pub struct Comment { pub bug_feedback: Vec<BugFeedback>, pub id: u32, pub karma: Karma, pub testcase_feedback: Vec<TestCaseFeedback>, pub text: String, pub timestamp: BodhiDate, pub update: Option<Update>, pub update_id: u32, pub user: User, pub user_id: u32, pub extra: HashMap<String, Value>, /* private fields */ }
data type that represents a comment on an update (including bug and test case feedback)

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
bug_feedback: Vec<BugFeedback>

list of bug feedback items

id: u32

numerical ID of this comment

karma: Karma

karma feedback associated with this comment

testcase_feedback: Vec<TestCaseFeedback>

list of test case feedback items

text: String

text of the comment

timestamp: BodhiDate

date & time this comment was published

update: Option<Update>

update this comment is associated with

update_id: u32

ID of the update this comment is associated with

user: User

user who submitted this comment

user_id: u32

user ID of the user who submitted this comment

extra: HashMap<String, Value>

catch-all for fields that are not explicitly deserialized