#[non_exhaustive]pub struct TestCaseFeedback {
pub comment_id: Option<u32>,
pub karma: Karma,
pub testcase: TestCase,
pub testcase_id: u32,
pub extra: HashMap<String, Value>,
}Expand description
data type that represents a feedback item for a test case that is associated with an update
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.comment_id: Option<u32>ID of the comment that this feedback is associated with
karma: Karmafeedback karma (positive, neutral, negative)
testcase: TestCasetest case that this feedback is associated with
testcase_id: u32ID of the test case that this feedback is associated with
extra: HashMap<String, Value>catch-all for fields that are not explicitly deserialized