BuildQuery

Struct BuildQuery 

pub struct BuildQuery<'a> { /* private fields */ }
data type encapsulating parameters for querying Builds

use bodhi::{BuildQuery, ContentType, FedoraRelease};

let query = BuildQuery::new();
// let builds = bodhi.paginated_request(&query).unwrap();

API documentation: https://bodhi.fedoraproject.org/docs/server_api/rest/builds.html#service-1

Implementations

Source

impl<'a> BuildQuery<'a>

pub fn new() -> Self

constructor for BuildQuery without any filters

pub fn rows_per_page(self, rows_per_page: u32) -> Self

override the default number of results per page

pub fn callback(self, fun: impl Fn(u32, u32) + 'a) -> Self

add callback function for progress reporting during long-running queries

The specified function will be called with the current result page and the number of total pages as arguments.

pub fn nvr(self, nvr: &'a str) -> Self

restrict query to builds matching a specific NVR

If this is the only parameter, consider using a BuildNVRQuery instead.

pub fn packages(self, packages: &'a [&'a str]) -> Self

restrict query to builds matching specific packages

pub fn releases(self, releases: &'a [FedoraRelease]) -> Self

restrict query to builds matching specific releases

pub fn updates(self, updates: &'a [&'a str]) -> Self

restrict query to builds matching specific updates