BodhiDate

Struct BodhiDate 

pub struct BodhiDate { /* private fields */ }
newtype wrapper around DateTime with custom conversion methods

The bodhi server uses a nonstandard format for datetime values, both in responses and in request parameters. This type is a wrapper around DateTime with custom implementations for parsing values from strings, formatting values as strings, and (de)serializing values in JSON.

The format string corresponding to the nonstandard format is defined in BODHI_DATETIME_FORMAT.